@@ -98,19 +98,19 @@ class Httpsqs(object):
         return ''
 
 def isOK(data):
-    if data is '' :
+    if data == '' :
         return False
-    if data is ERROR :
+    if data == ERROR :
         return False
-    if data is GET_END :
+    if data == GET_END :
         return False
-    if data is PUT_ERROR :
+    if data == PUT_ERROR :
         return False
-    if data is RESET_ERROR :
+    if data == RESET_ERROR :
         return False
-    if data is MAXQUEUE_CANCEL :
+    if data == MAXQUEUE_CANCEL :
         return False
-    if data is SYNCTIME_CANCEL :
+    if data == SYNCTIME_CANCEL :
         return False
     return True
     
